@@ -2,7 +2,7 @@
 //
 // rhyper.h: Rcpp R/C++ interface class library -- 
 //
-// Copyright (C) 2010 - 2011 Douglas Bates, Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2012 Douglas Bates, Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -23,12 +23,23 @@
 #define Rcpp__stats__random_rhyper_h
 
 namespace Rcpp {
-
+    namespace stats {
+        template <bool seed>
+        class HyperGenerator : public Generator<seed,double>{
+        public:
+            HyperGenerator( double nn1_, double nn2_, double kk_) : 
+                nn1(nn1_), nn2(nn2_), kk(kk_){}
+            inline double operator()() const { return ::Rf_rhyper(nn1, nn2, kk) ;}  
+        private:
+            double nn1, nn2, kk ;
+        } ;
+    }
+    
 	// Please make sure you to read Section 6.3 of "Writing R Extensions"
 	// about the need to call GetRNGstate() and PutRNGstate() when using 
 	// the random number generators provided by R.
 	inline NumericVector rhyper( int n, double nn1, double nn2, double kk ){
-		return NumericVector( n, ::Rf_rhyper, nn1, nn2, kk ) ;
+		return NumericVector( n, stats::HyperGenerator<false>( nn1, nn2, kk ) ) ;
 	}
 
 } // Rcpp
