@@ -2,7 +2,7 @@
 //
 // rpois.h: Rcpp R/C++ interface class library -- 
 //
-// Copyright (C) 2010 - 2011 Douglas Bates, Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2012 Douglas Bates, Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -23,12 +23,23 @@
 #define Rcpp__stats__random_rpois_h
 
 namespace Rcpp {
-
+    namespace stats{
+        
+        template <bool seed>
+    	class PoissonGenerator : public Generator<seed,double>{
+    	public:
+    	    PoissonGenerator( double mu_ ) : mu(mu_){}  
+    	    inline double operator()() const { return ::Rf_rpois(mu); }
+    	private:
+    	    double mu ;
+    	} ;
+    }  // stats
+    
 	// Please make sure you to read Section 6.3 of "Writing R Extensions"
 	// about the need to call GetRNGstate() and PutRNGstate() when using 
 	// the random number generators provided by R.
 	inline NumericVector rpois( int n, double mu ){
-		return NumericVector( n, ::Rf_rpois, mu ) ;
+		return NumericVector( n, stats::PoissonGenerator<false>(mu) ) ;
 	}
 
 } // Rcpp
