@@ -34,6 +34,7 @@ public:
     typedef typename VECTOR::converter_type converter_type ;
     typedef typename VECTOR::stored_type stored_type ;
     typedef typename VECTOR::Proxy Proxy ;
+    typedef typename VECTOR::const_Proxy const_Proxy ;
     
     Matrix() : VECTOR() {}
         
@@ -130,7 +131,7 @@ public:
                                                                   ) ;
     }
         
-    inline Proxy operator()( const size_t& i, const size_t& j) const {
+    inline const_Proxy operator()( const size_t& i, const size_t& j) const {
         return static_cast< const Vector<RTYPE>* >( this )->operator[]( 
                                                                        offset( i, j )
                                                                         ) ;
@@ -147,6 +148,9 @@ public:
     inline Column operator()( internal::NamedPlaceHolder, int i ){
         return Column( *this, i ) ;
     }
+    inline Column operator()( internal::NamedPlaceHolder, int i ) const {
+        return Column( *this, i ) ;
+    }
         
     inline Sub operator()( const Range& row_range, const Range& col_range){
         return Sub( const_cast<Matrix&>(*this), row_range, col_range ) ;
