@@ -49,8 +49,8 @@
 
 namespace internal{
 
-template <int RTYPE, typename VECTOR>
-class RangeIndexer {
+template <int RTYPE, bool NA, typename VECTOR>
+class RangeIndexer : public VectorBase<RTYPE, NA, RangeIndexer<RTYPE,NA,VECTOR> >  {
 public:
 	typedef typename VECTOR::Proxy Proxy ;
 	typedef typename VECTOR::iterator iterator ;
@@ -60,36 +60,36 @@ public:
 		start(vec_.begin() + range_.get_start() ), size_( range_.size() ) {}
 	
 		// TODO: size exceptions
-	template <bool NA, typename T>	
-	RangeIndexer& operator=( const Rcpp::VectorBase<RTYPE,NA,T>& x){
+	template <bool NA_, typename T>	
+	RangeIndexer& operator=( const Rcpp::VectorBase<RTYPE,NA_,T>& x){
 	    UNROLL_LOOP(=)
 	}
 	
-	template <bool NA, typename T>	
-	RangeIndexer& operator+=( const Rcpp::VectorBase<RTYPE,NA,T>& x){
+	template <bool NA_, typename T>	
+	RangeIndexer& operator+=( const Rcpp::VectorBase<RTYPE,NA_,T>& x){
 		 UNROLL_LOOP(+=)
 	}
 	
-	template <bool NA, typename T>	
-	RangeIndexer& operator*=( const Rcpp::VectorBase<RTYPE,NA,T>& x){
+	template <bool NA_, typename T>	
+	RangeIndexer& operator*=( const Rcpp::VectorBase<RTYPE,NA_,T>& x){
 		UNROLL_LOOP(*=)
 	}
 	
-	template <bool NA, typename T>	
-	RangeIndexer& operator-=( const Rcpp::VectorBase<RTYPE,NA,T>& x){
+	template <bool NA_, typename T>	
+	RangeIndexer& operator-=( const Rcpp::VectorBase<RTYPE,NA_,T>& x){
 		UNROLL_LOOP(-=)
 	}
 	
-	template <bool NA, typename T>	
-	RangeIndexer& operator/=( const Rcpp::VectorBase<RTYPE,NA,T>& x){
+	template <bool NA_, typename T>	
+	RangeIndexer& operator/=( const Rcpp::VectorBase<RTYPE,NA_,T>& x){
 		UNROLL_LOOP(/=)
 	}
 	
-	inline Proxy operator[]( int i ){
+	inline Proxy operator[]( int i ) const {
 	    return start[i] ;
 	}
 	
-	inline int size(){
+	inline int size() const {
 		return size_ ;
 	}
 	
