@@ -225,6 +225,20 @@ namespace traits {
 		typedef ::Rcpp::internal::generic_proxy<VECSXP> type ;
 	} ;
 
+	template <int RTYPE>
+	struct r_vector_const_proxy{
+		typedef const typename storage_type<RTYPE>::type& type ;
+	} ;                                            
+	// template<> struct r_vector_const_proxy<STRSXP> {
+	// 	typedef ::Rcpp::internal::string_proxy<STRSXP> type ;
+	// } ;
+	// template<> struct r_vector_const_proxy<EXPRSXP> {
+	// 	typedef ::Rcpp::internal::generic_proxy<EXPRSXP> type ;
+	// } ;
+	// template<> struct r_vector_const_proxy<VECSXP> {
+	// 	typedef ::Rcpp::internal::generic_proxy<VECSXP> type ;
+	// } ;
+
 	template <int RTYPE>
 	struct r_vector_iterator {
 		typedef typename storage_type<RTYPE>::type* type ;
@@ -241,12 +255,14 @@ namespace traits {
 	template<> struct r_vector_iterator<EXPRSXP> : proxy_based_iterator<EXPRSXP>{} ;
 	template<> struct r_vector_iterator<STRSXP> : proxy_based_iterator<STRSXP>{} ;
 
-	template<> struct r_vector_const_iterator<VECSXP> : proxy_based_iterator<VECSXP>{} ;
-	template<> struct r_vector_const_iterator<EXPRSXP> : proxy_based_iterator<EXPRSXP>{} ;
-	
-	template<> struct r_vector_const_iterator<STRSXP> {
-	    typedef CharacterVectorExtractionIterator type ;
-	} ;
+	// template <int RTYPE> struct proxy_based_const_iterator{
+	// 	typedef ::Rcpp::internal::SEXP_Iterator<RTYPE, Vector<RTYPE> > type ;
+	// } ;
+	// template<> struct r_vector_const_iterator<VECSXP> : proxy_based_const_iterator<VECSXP>{} ;
+	// template<> struct r_vector_const_iterator<EXPRSXP> : proxy_based_const_iterator<EXPRSXP>{} ;
+	// template<> struct r_vector_const_iterator<STRSXP> {
+	//     typedef CharacterVectorExtractionIterator type ;
+	// } ;
 
 }  // traits
 
