@@ -1,7 +1,7 @@
 #!/usr/bin/r -t
-# -*- mode: R; tab-width: 4 -*-
+# -*- mode: R; tab-width: 4; -*-
 #
-# Copyright (C) 2010 - 2011	Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2010 - 2012  Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -18,6 +18,10 @@
 # You should have received a copy of the GNU General Public License
 # along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
+.runThisTest <- Sys.getenv("RunAllRcppTests") == "yes"
+
+if (.runThisTest) {
+
 definitions <- function(){
     list(
 				  "runit_dbeta" = list(
@@ -614,3 +618,4 @@ test.stats.qt <- function( ) {
 # TODO: test.stats.qgamma
 # TODO: test.stats.(dq)chisq
 
+}
