@@ -114,6 +114,7 @@ RCPP_FUNCTION_2(SEXP, CppObject__finalize, XP_Class cl, SEXP obj){
 
 // .External functions
 extern "C" SEXP InternalFunction_invoke( SEXP args ){
+BEGIN_RCPP
 	SEXP p = CDR(args) ;
 	XP_Function fun( CAR(p) ) ; p = CDR(p) ;
 	
@@ -125,6 +126,7 @@ extern "C" SEXP InternalFunction_invoke( SEXP args ){
    		p = CDR(p) ;
    	}
    	return fun->operator()( cargs ) ;
+END_RCPP
 }
 
 extern "C" SEXP Module__invoke( SEXP args){
@@ -415,7 +417,7 @@ namespace Rcpp{
 	void class_Base::add_enum( const std::string& enum_name, const std::map<std::string, int>& value ){
 	    enums.insert( ENUM_MAP_PAIR( enum_name, value ) ) ;
 	}
-        
+    
 	CppClass::CppClass( SEXP x) : S4(x){}
 	
 	CppClass::CppClass( Module* p, class_Base* cl, std::string& buffer ) : S4("C++Class") {
@@ -434,6 +436,7 @@ namespace Rcpp{
 		slot( "docstring"   ) = cl->docstring ;
 		slot( "typeid" )      = cl->get_typeinfo_name() ;
 		slot( "enums"  )      = cl->enums ;
+		slot( "parents" )     = cl->parents ;
 	}
 
 	CppObject::CppObject( Module* p, class_Base* clazz, SEXP xp ) : S4("C++Object") {
