@@ -45,3 +45,6 @@ void set_vector_elt(SEXP x, int i, SEXP value){
 }
 SEXP* get_vector_ptr(SEXP x){ return VECTOR_PTR(x) ; }
 
+// when we already know x is a CHARSXP
+const char* char_nocheck( SEXP x ){ return CHAR(x); }
+
